Package 'rk.forcats'

Title: An RKWard plugin package for factor manipulation using the 'forcats' library.
Description: An RKWard plugin package for factor manipulation using the 'forcats' library.
Authors: Alfonso Cano
Maintainer: Alfonso Cano <[email protected]>
License: GPL (>= 3)
Version: 0.1.8
Built: 2026-05-18 10:10:29 UTC
Source: https://github.com/AlfCano/rk.forcats

Help Index